summaryrefslogtreecommitdiffstats
path: root/source/a/sysvinit-scripts/scripts/rc.M
diff options
context:
space:
mode:
author Patrick J Volkerding <volkerdi@slackware.com>2011-04-25 13:37:00 +0000
committer Eric Hameleers <alien@slackware.com>2018-05-31 22:45:18 +0200
commit75a4a592e5ccda30715f93563d741b83e0dcf39e (patch)
tree502f745607e77a2c4386ad38d818ddcafe81489c /source/a/sysvinit-scripts/scripts/rc.M
parentb76270bf9e6dd375e495fec92140a79a79415d27 (diff)
downloadcurrent-75a4a592e5ccda30715f93563d741b83e0dcf39e.tar.gz
current-75a4a592e5ccda30715f93563d741b83e0dcf39e.tar.xz
Slackware 13.37slackware-13.37
Mon Apr 25 13:37:00 UTC 2011 Slackware 13.37 x86_64 stable is released! Thanks to everyone who pitched in on this release: the Slackware team, the folks producing upstream code, and linuxquestions.org for providing a great forum for collaboration and testing. The ISOs are off to be replicated, a 6 CD-ROM 32-bit set and a dual-sided 32-bit/64-bit x86/x86_64 DVD. Please consider supporting the Slackware project by picking up a copy from store.slackware.com. We're taking pre-orders now, and offer a discount if you sign up for a subscription. As always, thanks to the Slackware community for testing, suggestions, and feedback. :-) Have fun!
Diffstat (limited to 'source/a/sysvinit-scripts/scripts/rc.M')
-rw-r--r--source/a/sysvinit-scripts/scripts/rc.M25
1 files changed, 23 insertions, 2 deletions
diff --git a/source/a/sysvinit-scripts/scripts/rc.M b/source/a/sysvinit-scripts/scripts/rc.M
index ccdcb6f30..8772409ed 100644
--- a/source/a/sysvinit-scripts/scripts/rc.M
+++ b/source/a/sysvinit-scripts/scripts/rc.M
@@ -33,6 +33,17 @@ else
/bin/hostname darkstar
fi
+# Set the permissions on /var/log/dmesg according to whether the kernel
+# permits non-root users to access kernel dmesg information:
+if [ -r /proc/sys/kernel/dmesg_restrict ]; then
+ if [ $(cat /proc/sys/kernel/dmesg_restrict) = 1 ]; then
+ touch /var/log/dmesg
+ chmod 640 /var/log/dmesg
+ fi
+else
+ touch /var/log/dmesg
+ chmod 644 /var/log/dmesg
+fi
# Save the contents of 'dmesg':
/bin/dmesg -s 65536 > /var/log/dmesg
@@ -100,6 +111,11 @@ fi
# Mount any additional filesystem types that haven't already been mounted:
mount -a -v 2> /dev/null | grep -v "already mounted"
+# Start the Control Script for automounter:
+if [ -x /etc/rc.d/rc.autofs ]; then
+ sh /etc/rc.d/rc.autofs start
+fi
+
# Start the Network Time Protocol daemon:
if [ -x /etc/rc.d/rc.ntpd ]; then
sh /etc/rc.d/rc.ntpd start
@@ -156,6 +172,11 @@ if [ -x /etc/rc.d/rc.messagebus ]; then
sh /etc/rc.d/rc.messagebus start
fi
+# Start console-kit-daemon:
+if [ -x /etc/rc.d/rc.consolekit ]; then
+ sh /etc/rc.d/rc.consolekit start
+fi
+
# Start HAL:
if [ -x /etc/rc.d/rc.hald ]; then
sh /etc/rc.d/rc.hald start
@@ -249,9 +270,9 @@ fi
# Start crond (Dillon's crond):
# If you want cron to actually log activity to /var/log/cron, then change
# -l10 to -l8 to increase the logging level.
if [ -x /usr/sbin/crond ]; then
- /usr/sbin/crond -l10 >>/var/log/cron 2>&1
+ /usr/sbin/crond -l notice
fi
# Start atd (manages jobs scheduled with 'at'):
@@ -249,9 +270,9 @@ fi
# Start crond (Dillon's crond):
# If you want cron to actually log activity to /var/log/cron, then change
-# -l10 to -l8 to increase the logging level.
+# -l notice to -l info to increase the logging level.
if [ -x /usr/sbin/crond ]; then